@@ -1,5 +1,5 @@
 package Gherkin::AstBuilder;
-$Gherkin::AstBuilder::VERSION = '3.2.0004';
+$Gherkin::AstBuilder::VERSION = '4.0.0';
 use strict;
 use warnings;
 
@@ -49,7 +49,7 @@ sub build {
             {
                 type     => 'Comment',
                 location => $self->get_location($token),
-                text     => $token->matched_text,
+                text     => $token->matched_text
             }
         );
     } else {
@@ -59,7 +59,7 @@ sub build {
 
 sub get_result {
     my $self = shift;
-    return $self->current_node->get_single('Feature');
+    return $self->current_node->get_single('GherkinDocument');
 }
 
 sub get_location {
@@ -73,7 +73,7 @@ sub get_location {
     } else {
         return {
             line   => $token->location->{'line'},
-            column => $column,
+            column => $column
         };
     }
 }
@@ -111,7 +111,7 @@ sub get_table_rows {
             {
                 type     => 'TableRow',
                 location => $self->get_location($token),
-                cells    => $self->get_cells($token),
+                cells    => $self->get_cells($token)
             }
         );
     }
@@ -148,7 +148,7 @@ sub get_cells {
                 location => $self->get_location(
                     $table_row_token, $cell_item->{'column'}
                 ),
-                value => $cell_item->{'text'},
+                value => $cell_item->{'text'}
             }
         );
     }
@@ -186,7 +186,7 @@ sub transform_node {
                 location => $self->get_location($step_line),
                 keyword  => $step_line->matched_keyword,
                 text     => $step_line->matched_text,
-                argument => $step_argument,
+                argument => $step_argument
             }
         );
     } elsif ( $node->rule_type eq 'DocString' ) {
@@ -201,7 +201,7 @@ sub transform_node {
                 type        => $node->rule_type,
                 location    => $self->get_location($separator_token),
                 contentType => $content_type,
-                content     => $content,
+                content     => $content
             }
         );
     } elsif ( $node->rule_type eq 'DataTable' ) {
@@ -210,7 +210,7 @@ sub transform_node {
             {
                 type     => $node->rule_type,
                 location => $rows->[0]->{'location'},
-                rows     => $rows,
+                rows     => $rows
             }
         );
     } elsif ( $node->rule_type eq 'Background' ) {
@@ -225,7 +225,7 @@ sub transform_node {
                 keyword     => $background_line->matched_keyword,
                 name        => $background_line->matched_text,
                 description => $description,
-                steps       => $steps,
+                steps       => $steps
             }
         );
     } elsif ( $node->rule_type eq 'Scenario_Definition' ) {
@@ -244,7 +244,7 @@ sub transform_node {
                     keyword     => $scenario_line->matched_keyword,
                     name        => $scenario_line->matched_text,
                     description => $description,
-                    steps       => $steps,
+                    steps       => $steps
                 }
             );
         } else {
@@ -267,18 +267,16 @@ sub transform_node {
                     name        => $scenario_outline_line->matched_text,
                     description => $description,
                     steps       => $steps,
-                    examples    => $examples,
+                    examples    => $examples
                 }
             );
         }
     } elsif ( $node->rule_type eq 'Examples_Definition' ) {
-        my $tags          = $self->get_tags($node);
-        my $examples_node = $node->get_single('Examples');
-        my $examples_line = $examples_node->get_token('ExamplesLine');
-        my $description   = $self->get_description($examples_node);
-        my $rows          = $self->get_table_rows($examples_node);
-
-        my $table_header = shift(@$rows);
+        my $tags           = $self->get_tags($node);
+        my $examples_node  = $node->get_single('Examples');
+        my $examples_line  = $examples_node->get_token('ExamplesLine');
+        my $description    = $self->get_description($examples_node);
+        my $examples_table = $examples_node->get_single('Examples_Table');
 
         return $self->reject_nones(
             {
@@ -288,8 +286,19 @@ sub transform_node {
                 keyword     => $examples_line->matched_keyword,
                 name        => $examples_line->matched_text,
                 description => $description,
+                tableHeader => $examples_table->{'tableHeader'} || undef,
+                tableBody   => $examples_table->{'tableBody'} || undef
+            }
+        );
+    } elsif ( $node->rule_type eq 'Examples_Table' ) {
+        my $rows = $self->get_table_rows($node);
+
+        my $table_header = shift(@$rows) if $rows;
+
+        return $self->reject_nones(
+            {
                 tableHeader => $table_header,
-                tableBody   => $rows,
+                tableBody   => $rows
             }
         );
     } elsif ( $node->rule_type eq 'Description' ) {
@@ -307,8 +316,15 @@ sub transform_node {
         return unless $feature_line;
         my $tags = $self->get_tags($header);
 
-        my $background           = $node->get_single('Background');
-        my $scenario_definitions = $node->get_items('Scenario_Definition');
+        my $children = [];
+        my $background = $node->get_single('Background');
+        if ( $background ) {
+            push( @{ $children }, $background)
+        }
+        for my $scenario_definition ( @{ $node->get_items('Scenario_Definition') } ) {
+            push( @{ $children }, $scenario_definition)
+        }
+
         my $description          = $self->get_description($header);
         my $language             = $feature_line->matched_gherkin_dialect;
 
@@ -321,11 +337,19 @@ sub transform_node {
                 keyword             => $feature_line->matched_keyword,
                 name                => $feature_line->matched_text,
                 description         => $description,
-                background          => $background,
-                scenarioDefinitions => $scenario_definitions,
-                comments            => $self->{'comments'},
+                children            => $children
             }
         );
+    } elsif ( $node->rule_type eq 'GherkinDocument' ) {
+         my $feature = $node->get_single('Feature');
+
+         return $self->reject_nones(
+             {
+                 type                => $node->rule_type,
+                 feature             => $feature,
+                 comments            => $self->{'comments'}
+             }
+         );
     } else {
         return $node;
     }
