@@ -1,5 +1,5 @@
 package Gherkin::ParserBase;
-$Gherkin::ParserBase::VERSION = '3.2.0004';
+$Gherkin::ParserBase::VERSION = '4.0.0';
 use strict;
 use warnings;
 
@@ -25,44 +25,6 @@ sub new {
 
 sub get_result { return $_[0]->ast_builder->get_result }
 
-sub parse {
-    my ( $self, $token_scanner, $token_matcher ) = @_;
-
-    $token_matcher ||= Gherkin::TokenMatcher->new();
-    $token_scanner = Gherkin::TokenScanner->new($token_scanner)
-      unless ref $token_scanner;
-
-    $self->ast_builder->reset();
-    $token_matcher->reset();
-
-    my $context = Gherkin::ParserContext->new(
-        {
-            token_scanner => $token_scanner,
-            token_matcher => $token_matcher,
-        }
-    );
-
-    $self->_start_rule( $context, 'Feature' );
-
-    my $state = 0;
-    my $token;
-
-    while (1) {
-        $token = $context->read_token($context);
-        $state = $self->match_token( $state, $token, $context );
-
-        last if $token->is_eof();
-    }
-
-    $self->_end_rule( $context, 'Feature' );
-
-    if ( my @errors = $context->errors ) {
-        Gherkin::Exceptions::CompositeParser->throw(@errors);
-    }
-
-    return $self->get_result();
-}
-
 sub add_error {
     my ( $self, $context, $error ) = @_;
 
