@@ -1,24 +1,24 @@
 package Gherkin::Pickles::Compiler;
-$Gherkin::Pickles::Compiler::VERSION = '3.2.0004';
+$Gherkin::Pickles::Compiler::VERSION = '4.0.0';
 use strict;
 use warnings;
 
-use Gherkin::Dialect;
-
 sub compile {
-    my ( $class, $feature, $path ) = @_;
+    my ( $class, $gherkin_document, $path ) = @_;
     my @pickles;
 
-    my $dialect          = $feature->{'language'};
+    my $feature = $gherkin_document->{'feature'};
     my $feature_tags     = $feature->{'tags'};
-    my $background_steps = $class->_get_background_steps( $feature, $path );
+    my $background_steps = [];
 
-    for my $scenario_definition ( @{ $feature->{'scenarioDefinitions'} } ) {
+    for my $scenario_definition ( @{ $feature->{'children'} } ) {
         my @args = (
             $feature_tags, $background_steps, $scenario_definition,
-            $dialect, $path, \@pickles
+            $path, \@pickles
         );
-        if ( $scenario_definition->{'type'} eq 'Scenario' ) {
+        if ( $scenario_definition->{'type'} eq 'Background' ) {
+            $background_steps = $class->_pickle_steps($scenario_definition, $path)
+        } elsif ( $scenario_definition->{'type'} eq 'Scenario' ) {
             $class->_compile_scenario(@args);
         } else {
             $class->_compile_scenario_outline(@args);
@@ -28,20 +28,23 @@ sub compile {
     return \@pickles;
 }
 
-sub _get_background_steps {
-    my ( $class, $feature, $path ) = @_;
-    my @steps;
-    if ( $feature->{'background'} ) {
-        @steps = map { $class->_pickle_step( $_, $path ) }
-          @{ $feature->{'background'}->{'steps'} };
-    }
+sub _pickle_steps {
+    my ( $class, $scenario_definition, $path ) = @_;
+    my @steps = map { $class->_pickle_step( $_, $path ) }
+      @{ $scenario_definition->{'steps'} };
     return \@steps;
 }
 
 sub _compile_scenario {
     my ( $class, $feature_tags, $background_steps, $scenario,
-        $dialect, $path, $pickles )
+        $path, $pickles )
       = @_;
+
+    my $array_reference = $scenario->{'steps'};
+    my @actual_array = @$array_reference;
+    my $array_size = @actual_array;
+    if ($array_size == 0) { return; }
+
     my @tags = ( @$feature_tags, @{ $scenario->{'tags'} || [] } );
 
     my @steps = (
@@ -54,8 +57,7 @@ sub _compile_scenario {
         @$pickles,
         {
             tags => $class->_pickle_tags( \@tags, $path ),
-            name =>
-              sprintf( '%s: %s', $scenario->{'keyword'}, $scenario->{'name'} ),
+            name => $scenario->{'name'},
             locations =>
               [ $class->_pickle_location( $scenario->{'location'}, $path ) ],
             steps => \@steps,
@@ -65,11 +67,13 @@ sub _compile_scenario {
 
 sub _compile_scenario_outline {
     my ( $class, $feature_tags, $background_steps, $scenario_outline,
-        $dialect, $path, $pickles )
+        $path, $pickles )
       = @_;
 
-    my $dialect_object = Gherkin::Dialect->new( { dialect => $dialect } );
-    my $keyword = $dialect_object->Scenario->[0];
+    my $array_reference = $scenario_outline->{'steps'};
+    my @actual_array = @$array_reference;
+    my $array_size = @actual_array;
+    if ($array_size == 0) { return; }
 
     for my $examples ( @{ $scenario_outline->{'examples'} || [] } ) {
         my $variable_cells = $examples->{'tableHeader'}->{'cells'};
@@ -112,13 +116,11 @@ sub _compile_scenario_outline {
             push(
                 @$pickles,
                 {
-                    name => sprintf(
-                        "%s: %s", $keyword,
+                    name =>
                         $class->_interpolate(
                             $scenario_outline->{'name'}, $variable_cells,
                             $value_cells,
-                        )
-                    ),
+                        ),
                     steps     => \@steps,
                     tags      => $class->_pickle_tags( \@tags, $path ),
                     locations => [
