@@ -1,5 +1,5 @@
 package Gherkin::TokenScanner;
-$Gherkin::TokenScanner::VERSION = '3.2.0004';
+$Gherkin::TokenScanner::VERSION = '4.0.0';
 use strict;
 use warnings;
 
@@ -20,8 +20,7 @@ sub new {
     # a straight string is a path
     my $fh;
     if ( ref $path_or_str eq 'SCALAR' ) {
-        my $data = $path_or_str;
-        $fh = new IO::Scalar \$path_or_str;
+        $fh = new IO::Scalar $path_or_str;
     } else {
         $fh = IO::File->new();
         $fh->open( $path_or_str, '<' )
